#!/usr/bin/env bash

rm -rf .lake/build
lake exe user_attr
